Learn R Programming

foodwebWrapper (version 1.1.0)

consolidate: consolidate

Description

create a permutation list of package names for re-ordering rows and columns of matrix m, in decreasing order of function counts per package

Usage

consolidate(v)

Value

returns a list whose components are character vector for permuting order of m

Arguments

v

character vector of package names component of return value of find_funz()

Examples

Run this code
if(interactive()){
load("data/x_v.RData")
l<-consolidate(x_v)
}

Run the code above in your browser using DataLab