Learn R Programming

foodwebWrapper (version 1.1.0)

find_funz: find_funz

Description

determine in which R package a function ‘resides’

Usage

find_funz(packs, rfuns)

Value

returns vector of character strings, names are functions and values are packages

Arguments

packs

list of character strings containing the names of the packages

rfuns

list of character strings containing the names of functions in packs to which the result is to be restricted

Examples

Run this code
if(interactive()){
load("data/x_packages.RData")
load("data/x_funs.RData")
find_funz(packs=x_packages,rfuns=x_funs)
}

Run the code above in your browser using DataLab