powered by
rearrange the order of rows or columns of matrix based on entries in a vector
rearrangeM(m, v2)
returns rearranged version of m
character matrix return value of concatPackFunc2()
list whose components are package names for permuting order of m, return value of consolidate()
if(interactive()){ load("data/x_m.RData") load("data/x_v2.RData") m2<-rearrangeM(x_m,x_v2) }
Run the code above in your browser using DataLab