powered by
create a permutation list of package names for re-ordering rows and columns of matrix m, in decreasing order of function counts per package
consolidate(v)
returns a list whose components are character vector for permuting order of m
character vector of package names component of return value of find_funz()
if(interactive()){ load("data/x_v.RData") l<-consolidate(x_v) }
Run the code above in your browser using DataLab