powered by
determine in which R package a function ‘resides’
find_funz(packs, rfuns)
returns vector of character strings, names are functions and values are packages
list of character strings containing the names of the packages
list of character strings containing the names of functions in packs to which the result is to be restricted
if(interactive()){ load("data/x_packages.RData") load("data/x_funs.RData") find_funz(packs=x_packages,rfuns=x_funs) }
Run the code above in your browser using DataLab